login

Function login 

pub async fn login() -> Result<Token, Error>
Open a browser-based PKCE login flow and return the resulting OAuth token.

Prints the authorization URL to stdout so the user can open it manually if the browser does not open automatically. Times out after 120 seconds.